@@ -17,9 +17,9 @@ pub enum Visibility {
 impl From<bool> for Visibility {
     fn from(source: bool) -> Self {
         if source {
-            Visibility::Visible.into()
+            Visibility::Visible
         } else {
-            Visibility::Hidden.into()
+            Visibility::Hidden
         }
     }
 }
